pub struct Sample {
pub buffer: [Vec<f32>; 2],
}Fields
buffer: [Vec<f32>; 2]Implementations
Sourceimpl Sample
impl Sample
pub fn new() -> Sample
pub fn with_size(len: usize) -> Sample
pub fn from_mono(buffer: &[f32]) -> Sample
pub fn length(&self) -> u64
pub fn record(&mut self, data: &[&[f32]])
pub fn overdub( &mut self, time_in_samples: u64, data: &[&[f32]], speed: LooperSpeed, )
pub fn replace(&mut self, time_in_samples: u64, data: &[&[f32]])
pub fn clear(&mut self)
Sourcepub fn xfade(
&mut self,
xfade_size: usize,
start_time_in_fade: u64,
time_in_samples: u64,
data: &[&[f32]],
direction: XfadeDirection,
f: fn(f32) -> f32,
)
pub fn xfade( &mut self, xfade_size: usize, start_time_in_fade: u64, time_in_samples: u64, data: &[&[f32]], direction: XfadeDirection, f: fn(f32) -> f32, )
Performs a crossfade with the existing buffer using the given function The fade direction refers to the given sample – i.e., a fade in starts with 100% of the existing sample, and ends at 100% of the new sample.