[][src]Struct loopers_engine::sample::Sample

pub struct Sample {
    pub buffer: [Vec<f32>; 2],
}

Fields

buffer: [Vec<f32>; 2]

Implementations

impl Sample[src]

pub fn new() -> Sample[src]

pub fn with_size(len: usize) -> Sample[src]

pub fn from_mono(buffer: &[f32]) -> Sample[src]

pub fn length(&self) -> u64[src]

pub fn record(&mut self, data: &[&[f32]])[src]

pub fn overdub(&mut self, time_in_samples: u64, data: &[&[f32]])[src]

pub fn replace(&mut self, time_in_samples: u64, data: &[&[f32]])[src]

pub fn clear(&mut self)[src]

pub fn xfade(
    &mut self,
    xfade_size: usize,
    start_time_in_fade: u64,
    time_in_samples: u64,
    data: &[&[f32]],
    direction: XfadeDirection,
    f: fn(_: f32) -> f32
)
[src]

Performs a crossfade with the existing buffer using the given function The fade direction refers to the given sample -- i.e., a fade in starts with 100% of the existing sample, and ends at 100% of the new sample.